@@ -19,12 +19,12 @@
 
 use crate::bls12383::big;
 use crate::bls12383::big::BIG;
-use crate::bls12383::dbig::DBIG;
 use crate::bls12383::ecp;
-use crate::bls12383::fp;
-use crate::bls12383::fp::FP;
 use crate::bls12383::fp2::FP2;
 use crate::bls12383::rom;
+use crate::bls12383::fp;
+use crate::bls12383::fp::FP;
+use crate::bls12383::dbig::DBIG;
 
 #[derive(Clone)]
 pub struct ECP2 {
@@ -38,7 +38,7 @@ impl std::fmt::Debug for ECP2 {
     fn fmt(&self, formatter: &mut std::fmt::Formatter) -> std::fmt::Result {
         write!(formatter, "{}", self.tostring())
     }
-}
+}    
 
 #[cfg(feature = "std")]
 impl std::fmt::Display for ECP2 {
@@ -75,7 +75,7 @@ impl ECP2 {
     }
 
     /* construct this from x - but set to O if not on curve */
-    pub fn new_fp2(ix: &FP2, s: isize) -> ECP2 {
+    pub fn new_fp2(ix: &FP2, s:isize) -> ECP2 {
         let mut E = ECP2::new();
         let mut h = FP::new();
         E.x.copy(&ix);
@@ -83,13 +83,13 @@ impl ECP2 {
         E.z.one();
         E.x.norm();
         let mut rhs = ECP2::rhs(&E.x);
-        if rhs.qr(Some(&mut h)) == 1 {
-            rhs.sqrt(Some(&h));
-            if rhs.sign() != s {
-                rhs.neg();
-            }
-            rhs.reduce();
-            E.y.copy(&rhs);
+ 	    if rhs.qr(Some(&mut h)) == 1 {
+		    rhs.sqrt(Some(&h));
+		    if rhs.sign() != s {
+			    rhs.neg();
+		    }
+		    rhs.reduce();
+		    E.y.copy(&rhs);
         } else {
             E.inf();
         }
@@ -228,102 +228,103 @@ impl ECP2 {
 
     /* convert to byte array */
     pub fn tobytes(&self, b: &mut [u8], compress: bool) {
-        const MB: usize = 2 * (big::MODBYTES as usize);
+        const MB:usize = 2*(big::MODBYTES as usize);
         let mut t: [u8; MB] = [0; MB];
-        let mut alt = false;
+        let mut alt=false;
         let mut W = ECP2::new();
         W.copy(self);
         W.affine();
         W.x.tobytes(&mut t);
 
-        if (fp::MODBITS - 1) % 8 <= 4 && ecp::ALLOW_ALT_COMPRESS {
-            alt = true;
+        if (fp::MODBITS-1)%8 <= 4 && ecp::ALLOW_ALT_COMPRESS {
+            alt=true;
         }
         if alt {
-            for i in 0..MB {
-                b[i] = t[i]
-            }
+		    for i in 0..MB {
+			    b[i]=t[i]
+		    }
             if !compress {
                 W.y.tobytes(&mut t);
                 for i in 0..MB {
-                    b[i + MB] = t[i];
-                }
+				    b[i+MB]=t[i];
+			    }
             } else {
-                b[0] |= 0x80;
-                if W.y.islarger() == 1 {
-                    b[0] |= 0x20;
-                }
-            }
-        } else {
-            for i in 0..MB {
-                b[i + 1] = t[i];
+                b[0]|=0x80;
+                if W.y.islarger()==1 {
+				    b[0]|=0x20;
+			    }
             }
+
+	    } else {
+		    for i in 0..MB {
+			    b[i+1]=t[i];
+		    }
             if !compress {
-                b[0] = 0x04;
+                b[0]=0x04;
                 W.y.tobytes(&mut t);
-                for i in 0..MB {
-                    b[i + MB + 1] = t[i];
-                }
+	            for i in 0..MB {
+			        b[i+MB+1]=t[i];
+			    }
             } else {
-                b[0] = 0x02;
+                b[0]=0x02;
                 if W.y.sign() == 1 {
-                    b[0] = 0x03;
-                }
+                    b[0]=0x03;
+			    }
             }
-        }
+	    }
     }
 
     /* convert from byte array to point */
     pub fn frombytes(b: &[u8]) -> ECP2 {
-        const MB: usize = 2 * (big::MODBYTES as usize);
+        const MB:usize = 2*(big::MODBYTES as usize);
         let mut t: [u8; MB] = [0; MB];
-        let typ = b[0] as isize;
-        let mut alt = false;
+        let typ=b[0] as isize;
+        let mut alt=false;
 
-        if (fp::MODBITS - 1) % 8 <= 4 && ecp::ALLOW_ALT_COMPRESS {
-            alt = true;
+        if (fp::MODBITS-1)%8 <= 4 && ecp::ALLOW_ALT_COMPRESS {
+            alt=true;
         }
 
-        if alt {
-            for i in 0..MB {
-                t[i] = b[i];
-            }
-            t[0] &= 0x1f;
-            let rx = FP2::frombytes(&t);
-            if (b[0] & 0x80) == 0 {
+	if alt {
+            for i in 0..MB  {
+			    t[i]=b[i];
+		    }
+            t[0]&=0x1f;
+            let rx=FP2::frombytes(&t);
+            if (b[0]&0x80)==0 {
                 for i in 0..MB {
-                    t[i] = b[i + MB];
-                }
-                let ry = FP2::frombytes(&t);
-                ECP2::new_fp2s(&rx, &ry)
+				    t[i]=b[i+MB];
+			    }
+                let ry=FP2::frombytes(&t);
+                ECP2::new_fp2s(&rx,&ry)
             } else {
-                let sgn = (b[0] & 0x20) >> 5;
-                let mut P = ECP2::new_fp2(&rx, 0);
-                let cmp = P.y.islarger();
+                let sgn=(b[0]&0x20)>>5;
+                let mut P=ECP2::new_fp2(&rx,0);
+                let cmp=P.y.islarger();
                 if (sgn == 1 && cmp != 1) || (sgn == 0 && cmp == 1) {
-                    P.neg();
-                }
+				    P.neg();
+			    }
                 P
             }
         } else {
             for i in 0..MB {
-                t[i] = b[i + 1];
+                 t[i]=b[i+1];
             }
-            let rx = FP2::frombytes(&t);
+            let rx=FP2::frombytes(&t);
             if typ == 0x04 {
-                for i in 0..MB {
-                    t[i] = b[i + MB + 1];
-                }
-                let ry = FP2::frombytes(&t);
-                ECP2::new_fp2s(&rx, &ry)
+		        for i in 0..MB {
+				    t[i]=b[i+MB+1];
+			    }
+		        let ry=FP2::frombytes(&t);
+		        ECP2::new_fp2s(&rx,&ry)
             } else {
-                ECP2::new_fp2(&rx, typ & 1)
+                ECP2::new_fp2(&rx,typ&1)
             }
         }
     }
 
     /* convert this to hex string */
-    #[cfg(feature = "std")]
+#[cfg(feature = "std")]
     pub fn tostring(&self) -> String {
         let mut W = ECP2::new();
         W.copy(self);
@@ -616,15 +617,15 @@ impl ECP2 {
     }
 
     #[allow(non_snake_case)]
-    pub fn cfp(&mut self) {
+    pub fn cfp(&mut self)  {
         let mut X = FP2::new_bigs(&BIG::new_ints(&rom::FRA), &BIG::new_ints(&rom::FRB));
         if ecp::SEXTIC_TWIST == ecp::M_TYPE {
             X.inverse(None);
             X.norm();
         }
         let x = BIG::new_ints(&rom::CURVE_BNX);
-        // Faster Hashing to G2 - Fuentes-Castaneda, Knapp and Rodriguez-Henriquez
-        // Q -> xQ + F(3xQ) + F(F(xQ)) + F(F(F(Q))).
+    // Faster Hashing to G2 - Fuentes-Castaneda, Knapp and Rodriguez-Henriquez
+    // Q -> xQ + F(3xQ) + F(F(xQ)) + F(F(F(Q))).
         if ecp::CURVE_PAIRING_TYPE == ecp::BN {
             let mut T = self.mul(&x);
             if ecp::SIGN_OF_X == ecp::NEGATIVEX {
@@ -645,8 +646,8 @@ impl ECP2 {
             T.frob(&X);
             self.add(&T);
         }
-        // Efficient hash maps to G2 on BLS curves - Budroni, Pintore
-        // Q -> x2Q -xQ -Q +F(xQ -Q) +F(F(2Q))
+    // Efficient hash maps to G2 on BLS curves - Budroni, Pintore
+    // Q -> x2Q -xQ -Q +F(xQ -Q) +F(F(2Q))
         if ecp::CURVE_PAIRING_TYPE > ecp::BN {
             let mut xQ = self.mul(&x);
             let mut x2Q = xQ.mul(&x);
@@ -669,6 +670,7 @@ impl ECP2 {
         }
     }
 
+
     /* P=u0.Q0+u1*Q1+u2*Q2+u3*Q3 */
     // Bos & Costello https://eprint.iacr.org/2013/458.pdf
     // Faz-Hernandez & Longa & Sanchez  https://eprint.iacr.org/2013/158.pdf
@@ -779,15 +781,15 @@ impl ECP2 {
         P
     }
 
-    /* Hunt and Peck a BIG to a curve point */
+/* Hunt and Peck a BIG to a curve point */
     #[allow(non_snake_case)]
     pub fn hap2point(h: &BIG) -> ECP2 {
         let mut Q: ECP2;
         let one = BIG::new_int(1);
-        let mut x = BIG::new_copy(&h);
+        let mut x =BIG::new_copy(&h);
         loop {
             let X = FP2::new_bigs(&one, &x);
-            Q = ECP2::new_fp2(&X, 0);
+            Q = ECP2::new_fp2(&X,0);
             if !Q.is_infinity() {
                 break;
             }
@@ -797,28 +799,24 @@ impl ECP2 {
         Q
     }
 
-    /* Constant time Map to Point */
+/* Constant time Map to Point */
     #[allow(unreachable_code)]
     #[allow(non_snake_case)]
     pub fn map2point(H: &FP2) -> ECP2 {
-        let mut T = FP2::new_copy(H); /**/
-        let sgn = T.sign(); /**/
+        let mut T=FP2::new_copy(H); /**/
+        let sgn=T.sign(); /**/
         if ecp::HTC_ISO_G2 == 0 {
-            // Shallue and van de Woestijne
-            /* */
-            let mut NY = FP2::new_int(1);
-            let mut Z = FP::new_int(fp::RIADZG2A);
-            let mut X1 = FP2::new_fp(&Z);
-            let mut X3 = FP2::new_copy(&X1);
-            let mut A = ECP2::rhs(&X1);
-            let mut W = FP2::new_copy(&A);
+    // Shallue and van de Woestijne
+/* */
+            let mut NY=FP2::new_int(1);
+            let mut Z=FP::new_int(fp::RIADZG2A);
+            let mut X1=FP2::new_fp(&Z);
+            let mut X3=FP2::new_copy(&X1);
+            let mut A=ECP2::rhs(&X1);
+            let mut W=FP2::new_copy(&A);
 
-            if fp::RIADZG2A == -1
-                && fp::RIADZG2B == 0
-                && ecp::SEXTIC_TWIST == ecp::M_TYPE
-                && rom::CURVE_B_I == 4
-            {
-                W.copy(&FP2::new_ints(2, 1));
+            if fp::RIADZG2A==-1 && fp::RIADZG2B==0 && ecp::SEXTIC_TWIST == ecp::M_TYPE && rom::CURVE_B_I==4 {
+                W.copy(&FP2::new_ints(2,1));
             } else {
                 W.sqrt(None);
             }
@@ -826,177 +824,160 @@ impl ECP2 {
             Z.mul(&s);
 
             T.sqr();
-            let mut Y = FP2::new_copy(&A);
-            Y.mul(&T);
-            T.copy(&NY);
-            T.add(&Y);
-            T.norm();
-            Y.rsub(&NY);
-            Y.norm();
-            NY.copy(&T);
-            NY.mul(&Y);
-
+            let mut Y=FP2::new_copy(&A); Y.mul(&T);
+            T.copy(&NY); T.add(&Y); T.norm();
+            Y.rsub(&NY); Y.norm();
+            NY.copy(&T); NY.mul(&Y); 
+        
             NY.pmul(&Z);
             NY.inverse(None);
 
             W.pmul(&Z);
-            if W.sign() == 1 {
+            if W.sign()==1 {
                 W.neg();
                 W.norm();
             }
             W.pmul(&Z);
-            W.mul(&H);
-            W.mul(&Y);
-            W.mul(&NY);
+            W.mul(&H); W.mul(&Y); W.mul(&NY);
 
-            X1.neg();
-            X1.norm();
-            X1.div2();
-            let mut X2 = FP2::new_copy(&X1);
-            X1.sub(&W);
-            X1.norm();
-            X2.add(&W);
-            X2.norm();
-            A.dbl();
-            A.dbl();
-            A.norm();
-            T.sqr();
-            T.mul(&NY);
-            T.sqr();
+            X1.neg(); X1.norm(); X1.div2();
+            let mut X2=FP2::new_copy(&X1);
+            X1.sub(&W); X1.norm();
+            X2.add(&W); X2.norm();
+            A.dbl(); A.dbl(); A.norm();
+            T.sqr(); T.mul(&NY); T.sqr();
             A.mul(&T);
-            X3.add(&A);
-            X3.norm();
+            X3.add(&A); X3.norm();
 
             Y.copy(&ECP2::rhs(&X2));
-            X3.cmove(&X2, Y.qr(None));
+            X3.cmove(&X2,Y.qr(None));
             Y.copy(&ECP2::rhs(&X1));
-            X3.cmove(&X1, Y.qr(None));
+            X3.cmove(&X1,Y.qr(None));
             Y.copy(&ECP2::rhs(&X3));
             Y.sqrt(None);
 
-            let ne = Y.sign() ^ sgn;
-            W.copy(&Y);
-            W.neg();
-            W.norm();
-            Y.cmove(&W, ne);
+            let ne=Y.sign()^sgn;
+            W.copy(&Y); W.neg(); W.norm();
+            Y.cmove(&W,ne);
 
-            return ECP2::new_fp2s(&X3, &Y);
-        /* */
+            return ECP2::new_fp2s(&X3,&Y);
+/* */
         } else {
-            /* CAHCZS
-                        let NY=FP2::new_int(1);
-                        let Ad=FP2::new_bigs(&BIG::new_ints(&rom::CURVE_ADR),&BIG::new_ints(&rom::CURVE_ADI));
-                        let Bd=FP2::new_bigs(&BIG::new_ints(&rom::CURVE_BDR),&BIG::new_ints(&rom::CURVE_BDI));
-                        let ZZ=FP2::new_ints(fp::RIADZG2A,fp::RIADZG2B);
-                        let mut hint=FP::new();
+/* CAHCZS
+            let NY=FP2::new_int(1);
+            let Ad=FP2::new_bigs(&BIG::new_ints(&rom::CURVE_ADR),&BIG::new_ints(&rom::CURVE_ADI));
+            let Bd=FP2::new_bigs(&BIG::new_ints(&rom::CURVE_BDR),&BIG::new_ints(&rom::CURVE_BDI));  
+            let ZZ=FP2::new_ints(fp::RIADZG2A,fp::RIADZG2B);
+            let mut hint=FP::new();
 
-                        T.sqr();
-                        T.mul(&ZZ);
-                        let mut W=FP2::new_copy(&T);
-                        W.add(&NY); W.norm();
+            T.sqr();
+            T.mul(&ZZ);
+            let mut W=FP2::new_copy(&T);
+            W.add(&NY); W.norm();
 
-                        W.mul(&T);
-                        let mut D=FP2::new_copy(&Ad);
-                        D.mul(&W);
+            W.mul(&T);
+            let mut D=FP2::new_copy(&Ad);
+            D.mul(&W);
+    
+            W.add(&NY); W.norm();
+            W.mul(&Bd);
+            W.neg(); W.norm();
 
-                        W.add(&NY); W.norm();
-                        W.mul(&Bd);
-                        W.neg(); W.norm();
+            let mut X2=FP2::new_copy(&W);
+            let mut X3=FP2::new_copy(&T);
+            X3.mul(&X2);
 
-                        let mut X2=FP2::new_copy(&W);
-                        let mut X3=FP2::new_copy(&T);
-                        X3.mul(&X2);
+            let mut GX1=FP2::new_copy(&X2); GX1.sqr();
+            let mut D2=FP2::new_copy(&D); D2.sqr();
 
-                        let mut GX1=FP2::new_copy(&X2); GX1.sqr();
-                        let mut D2=FP2::new_copy(&D); D2.sqr();
+            W.copy(&Ad); W.mul(&D2); GX1.add(&W); GX1.norm(); GX1.mul(&X2); D2.mul(&D); W.copy(&Bd); W.mul(&D2); GX1.add(&W); GX1.norm(); // x^3+Ax+b
 
-                        W.copy(&Ad); W.mul(&D2); GX1.add(&W); GX1.norm(); GX1.mul(&X2); D2.mul(&D); W.copy(&Bd); W.mul(&D2); GX1.add(&W); GX1.norm(); // x^3+Ax+b
+            W.copy(&GX1); W.mul(&D);
+            let qr=W.qr(Some(&mut hint));
+            D.copy(&W); D.inverse(Some(&hint));
+            D.mul(&GX1);
+            X2.mul(&D);
+            X3.mul(&D);
+            T.mul(&H);
+            D2.copy(&D); D2.sqr();
 
-                        W.copy(&GX1); W.mul(&D);
-                        let qr=W.qr(Some(&mut hint));
-                        D.copy(&W); D.inverse(Some(&hint));
-                        D.mul(&GX1);
-                        X2.mul(&D);
-                        X3.mul(&D);
-                        T.mul(&H);
-                        D2.copy(&D); D2.sqr();
+            D.copy(&D2); D.mul(&T);
+            T.copy(&W); T.mul(&ZZ);
 
-                        D.copy(&D2); D.mul(&T);
-                        T.copy(&W); T.mul(&ZZ);
+            let mut s=FP::new_big(&BIG::new_ints(&rom::CURVE_HTPC2));
+            s.mul(&hint);
 
-                        let mut s=FP::new_big(&BIG::new_ints(&rom::CURVE_HTPC2));
-                        s.mul(&hint);
+            X2.cmove(&X3,1-qr);
+            W.cmove(&T,1-qr);
+            D2.cmove(&D,1-qr);
+            hint.cmove(&s,1-qr);
 
-                        X2.cmove(&X3,1-qr);
-                        W.cmove(&T,1-qr);
-                        D2.cmove(&D,1-qr);
-                        hint.cmove(&s,1-qr);
+            let mut Y=FP2::new_copy(&W); Y.sqrt(Some(&hint));
+            Y.mul(&D2);
 
-                        let mut Y=FP2::new_copy(&W); Y.sqrt(Some(&hint));
-                        Y.mul(&D2);
+            let ne=Y.sign()^sgn;
+            W.copy(&Y); W.neg(); W.norm();
+            Y.cmove(&W,ne);
 
-                        let ne=Y.sign()^sgn;
-                        W.copy(&Y); W.neg(); W.norm();
-                        Y.cmove(&W,ne);
+            let mut k=0;
+            let isox=ecp::HTC_ISO_G2;
+            let isoy=3*(isox-1)/2;
 
-                        let mut k=0;
-                        let isox=ecp::HTC_ISO_G2;
-                        let isoy=3*(isox-1)/2;
+        // xnum
+            let mut xnum=FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k])); k+=1;
+            for _ in 0..isox {
+                xnum.mul(&X2);
+                xnum.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
+                xnum.norm();
+            }
+        //xden
+            let mut xden=FP2::new_copy(&X2);
+            xden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
+            xden.norm();
+            for _ in 0..isox-2 {
+                xden.mul(&X2);
+                xden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
+                xden.norm();                
+            }
+        //ynum
+            let mut ynum=FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k])); k+=1;            
+            for _ in 0..isoy {
+                ynum.mul(&X2);
+                ynum.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
+                ynum.norm();
+            }
+        //yden
+            let mut yden=FP2::new_copy(&X2);
+            yden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
+            yden.norm(); 
+            for _ in 0..isoy-1 {
+                yden.mul(&X2);
+                yden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
+                yden.norm();
+            }
+            ynum.mul(&Y);
 
-                    // xnum
-                        let mut xnum=FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k])); k+=1;
-                        for _ in 0..isox {
-                            xnum.mul(&X2);
-                            xnum.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
-                            xnum.norm();
-                        }
-                    //xden
-                        let mut xden=FP2::new_copy(&X2);
-                        xden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
-                        xden.norm();
-                        for _ in 0..isox-2 {
-                            xden.mul(&X2);
-                            xden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
-                            xden.norm();
-                        }
-                    //ynum
-                        let mut ynum=FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k])); k+=1;
-                        for _ in 0..isoy {
-                            ynum.mul(&X2);
-                            ynum.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
-                            ynum.norm();
-                        }
-                    //yden
-                        let mut yden=FP2::new_copy(&X2);
-                        yden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
-                        yden.norm();
-                        for _ in 0..isoy-1 {
-                            yden.mul(&X2);
-                            yden.add(&FP2::new_bigs(&BIG::new_ints(&rom::PCR[k]),&BIG::new_ints(&rom::PCI[k]))); k+=1;
-                            yden.norm();
-                        }
-                        ynum.mul(&Y);
+            let mut Q=ECP2::new();
+            T.copy(&xnum); T.mul(&yden);
+            Q.x.copy(&T);
+            T.copy(&ynum); T.mul(&xden);
+            Q.y.copy(&T);
+            T.copy(&xden); T.mul(&yden);
+            Q.z.copy(&T);
+            return Q;
+CAHCZF */
 
-                        let mut Q=ECP2::new();
-                        T.copy(&xnum); T.mul(&yden);
-                        Q.x.copy(&T);
-                        T.copy(&ynum); T.mul(&xden);
-                        Q.y.copy(&T);
-                        T.copy(&xden); T.mul(&yden);
-                        Q.z.copy(&T);
-                        return Q;
-            CAHCZF */
         }
         ECP2::new()
     }
 
-    /* Map byte string to curve point */
+/* Map byte string to curve point */
     #[allow(non_snake_case)]
     pub fn mapit(h: &[u8]) -> ECP2 {
         let q = BIG::new_ints(&rom::MODULUS);
         let mut dx = DBIG::frombytes(h);
-        let x = dx.dmod(&q);
-        let mut P = ECP2::hap2point(&x);
+        let x=dx.dmod(&q);
+        let mut P=ECP2::hap2point(&x);
         P.cfp();
         P
     }
