@@ -24,13 +24,13 @@ use crate::bls48581::ecp8::ECP8;
 use crate::bls48581::fp::FP;
 use crate::bls48581::fp16::FP16;
 use crate::bls48581::fp2::FP2;
-use crate::bls48581::fp48;
 use crate::bls48581::fp48::FP48;
+use crate::bls48581::fp48;
 use crate::bls48581::fp8::FP8;
 use crate::bls48581::rom;
 
 #[allow(non_snake_case)]
-fn dbl(A: &mut ECP8, aa: &mut FP8, bb: &mut FP8, cc: &mut FP8) {
+fn dbl(A: &mut ECP8,aa: &mut FP8, bb: &mut FP8, cc: &mut FP8) {
     cc.copy(&A.getpx()); //X
     let mut yy = FP8::new_copy(&A.getpy()); //Y
     bb.copy(&A.getpz()); //Z
@@ -42,27 +42,27 @@ fn dbl(A: &mut ECP8, aa: &mut FP8, bb: &mut FP8, cc: &mut FP8) {
     bb.sqr(); //Z^2
 
     aa.dbl();
-    aa.neg();
-    aa.norm();
+    aa.neg(); aa.norm();
     aa.times_i();
 
     let sb = 3 * rom::CURVE_B_I;
     bb.imul(sb);
     cc.imul(3);
     if ecp::SEXTIC_TWIST == ecp::D_TYPE {
-        yy.times_i();
-        cc.times_i();
+	yy.times_i();
+	cc.times_i();
     }
     if ecp::SEXTIC_TWIST == ecp::M_TYPE {
-        bb.times_i();
+	bb.times_i();
     }
     bb.sub(&yy);
     bb.norm();
     A.dbl();
+
 }
 
 #[allow(non_snake_case)]
-fn add(A: &mut ECP8, B: &ECP8, aa: &mut FP8, bb: &mut FP8, cc: &mut FP8) {
+fn add(A: &mut ECP8, B: &ECP8,  aa: &mut FP8, bb: &mut FP8, cc: &mut FP8) {
     aa.copy(&A.getpx()); // X1
     cc.copy(&A.getpy()); // Y1
     let mut t1 = FP8::new_copy(&A.getpz()); // Z1
@@ -100,11 +100,11 @@ fn linedbl(A: &mut ECP8, qx: &FP, qy: &FP) -> FP48 {
     let mut a = FP16::new();
     let mut b = FP16::new();
     let mut c = FP16::new();
-    let mut aa = FP8::new();
-    let mut bb = FP8::new();
-    let mut cc = FP8::new();
+    let mut aa = FP8::new(); 
+    let mut bb = FP8::new(); 
+    let mut cc = FP8::new(); 
 
-    dbl(A, &mut aa, &mut bb, &mut cc);
+    dbl(A,&mut aa,&mut bb,&mut cc);
 
     cc.tmul(qx);
     aa.tmul(qy);
@@ -117,8 +117,8 @@ fn linedbl(A: &mut ECP8, qx: &FP, qy: &FP) -> FP48 {
         c.copy(&FP16::new_fp8(&cc));
         c.times_i();
     }
-
-    let mut res = FP48::new_fp16s(&a, &b, &c);
+  
+    let mut res= FP48::new_fp16s(&a, &b, &c);
     res.settype(fp48::SPARSER);
     res
 }
@@ -128,11 +128,11 @@ fn lineadd(A: &mut ECP8, B: &ECP8, qx: &FP, qy: &FP) -> FP48 {
     let mut a = FP16::new();
     let mut b = FP16::new();
     let mut c = FP16::new();
-    let mut aa = FP8::new();
-    let mut bb = FP8::new();
-    let mut cc = FP8::new();
+    let mut aa = FP8::new(); 
+    let mut bb = FP8::new(); 
+    let mut cc = FP8::new(); 
 
-    add(A, B, &mut aa, &mut bb, &mut cc);
+    add(A,B,&mut aa,&mut bb,&mut cc);
 
     cc.tmul(qx);
     aa.tmul(qy);
@@ -145,15 +145,15 @@ fn lineadd(A: &mut ECP8, B: &ECP8, qx: &FP, qy: &FP) -> FP48 {
         c.copy(&FP16::new_fp8(&cc));
         c.times_i();
     }
-
-    let mut res = FP48::new_fp16s(&a, &b, &c);
+  
+    let mut res= FP48::new_fp16s(&a, &b, &c);
     res.settype(fp48::SPARSER);
     res
 }
 
 /* prepare ate parameter, n=6u+2 (BN) or n=u (BLS), n3=3*n */
 #[allow(non_snake_case)]
-fn lbits(n3: &mut BIG, n: &mut BIG) -> usize {
+fn lbits(n3: &mut BIG,n: &mut BIG) -> usize {
     n.copy(&BIG::new_ints(&rom::CURVE_BNX));
     n3.copy(&n);
     n3.pmul(3);
@@ -164,19 +164,19 @@ fn lbits(n3: &mut BIG, n: &mut BIG) -> usize {
 /* prepare for multi-pairing */
 pub fn initmp() -> [FP48; ecp::ATE_BITS] {
     let r: [FP48; ecp::ATE_BITS] = [FP48::new_int(1); ecp::ATE_BITS];
-    return r;
+    return r
 }
 
 /* basic Miller loop */
-pub fn miller(r: &mut [FP48]) -> FP48 {
-    let mut res = FP48::new_int(1);
+pub fn miller(r:&mut [FP48]) -> FP48 {
+    let mut res=FP48::new_int(1);
     for i in (1..ecp::ATE_BITS).rev() {
         res.sqr();
         res.ssmul(&r[i]);
-        r[i].zero();
+	r[i].zero();
     }
 
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+    if ecp::SIGN_OF_X==ecp::NEGATIVEX {
         res.conj();
     }
     res.ssmul(&r[0]);
@@ -184,50 +184,48 @@ pub fn miller(r: &mut [FP48]) -> FP48 {
     res
 }
 
-fn pack(aa: &FP8, bb: &FP8, cc: &FP8) -> FP16 {
-    let mut i = FP8::new_copy(cc);
+fn pack(aa: &FP8,bb: &FP8,cc: &FP8) -> FP16 {
+    let mut i=FP8::new_copy(cc);
     i.inverse(None);
-    let mut a = FP8::new_copy(aa);
-    let mut b = FP8::new_copy(bb);
+    let mut a=FP8::new_copy(aa);
+    let mut b=FP8::new_copy(bb);
     a.mul(&i);
     b.mul(&i);
-    FP16::new_fp8s(&a, &b)
+    FP16::new_fp8s(&a,&b)
 }
 
 fn unpack(t: &FP16, qx: &FP, qy: &FP) -> FP48 {
-    let b: FP16;
-    let mut c: FP16;
-    let w = FP8::new_fp(qx);
+    let b:FP16;
+    let mut c:FP16;
+    let w=FP8::new_fp(qx);
 
-    let mut aa = t.geta();
-    let bb = t.getb();
+    let mut aa=t.geta();
+    let bb=t.getb();
     aa.tmul(qy);
-    let a = FP16::new_fp8s(&aa, &bb);
-
-    if ecp::SEXTIC_TWIST == ecp::D_TYPE {
-        b = FP16::new_fp8(&w);
-        c = FP16::new();
-    } else {
-        b = FP16::new();
-        c = FP16::new_fp8(&w);
-        c.times_i();
+    let a=FP16::new_fp8s(&aa,&bb);
+   
+    if ecp::SEXTIC_TWIST==ecp::D_TYPE {
+        b=FP16::new_fp8(&w);
+	c=FP16::new();
+    } else  {
+        b=FP16::new();
+	c=FP16::new_fp8(&w); c.times_i();
     }
-    let mut v = FP48::new_fp16s(&a, &b, &c);
+    let mut v=FP48::new_fp16s(&a,&b,&c);
     v.settype(fp48::SPARSEST);
     v
 }
 
 #[allow(non_snake_case)]
-pub fn precomp(T: &mut [FP16], GV: &ECP8) {
+pub fn precomp(T: &mut [FP16],GV: &ECP8) {
     let mut n = BIG::new();
     let mut n3 = BIG::new();
-    let nb = lbits(&mut n3, &mut n);
-    let mut aa = FP8::new();
-    let mut bb = FP8::new();
-    let mut cc = FP8::new();
+    let nb=lbits(&mut n3,&mut n);
+    let mut aa = FP8::new(); 
+    let mut bb = FP8::new(); 
+    let mut cc = FP8::new(); 
 
-    let mut P = ECP8::new();
-    P.copy(GV);
+    let mut P=ECP8::new(); P.copy(GV);
 
     let mut A = ECP8::new();
 
@@ -235,29 +233,27 @@ pub fn precomp(T: &mut [FP16], GV: &ECP8) {
     let mut NP = ECP8::new();
     NP.copy(&P);
     NP.neg();
-    let mut j = 0;
+    let mut j=0;
 
-    for i in (1..nb - 1).rev() {
-        dbl(&mut A, &mut aa, &mut bb, &mut cc);
-        T[j].copy(&pack(&aa, &bb, &cc));
-        j += 1;
-        let bt = n3.bit(i) - n.bit(i);
-        if bt == 1 {
-            add(&mut A, &P, &mut aa, &mut bb, &mut cc);
-            T[j].copy(&pack(&aa, &bb, &cc));
-            j += 1;
-        }
-        if bt == -1 {
-            add(&mut A, &NP, &mut aa, &mut bb, &mut cc);
-            T[j].copy(&pack(&aa, &bb, &cc));
-            j += 1;
-        }
+    for i in (1..nb-1).rev() {
+        dbl(&mut A,&mut aa,&mut bb,&mut cc);
+	T[j].copy(&pack(&aa,&bb,&cc)); j+=1;
+	let bt=n3.bit(i)-n.bit(i);
+	if bt==1 {
+	    add(&mut A,&P,&mut aa,&mut bb,&mut cc);
+	    T[j].copy(&pack(&aa,&bb,&cc)); j+=1;
+	}
+	if bt==-1 {
+	    add(&mut A,&NP,&mut aa,&mut bb,&mut cc);
+	    T[j].copy(&pack(&aa,&bb,&cc)); j+=1;
+	}
     }
+
 }
 
 /* Accumulate another set of line functions for n-pairing, assuming precomputation on G2 */
 #[allow(non_snake_case)]
-pub fn another_pc(r: &mut [FP48], T: &[FP16], QV: &ECP) {
+pub fn another_pc(r:&mut [FP48],T: &[FP16],QV: &ECP) {
     let mut n = BIG::new();
     let mut n3 = BIG::new();
 
@@ -265,7 +261,7 @@ pub fn another_pc(r: &mut [FP48], T: &[FP16], QV: &ECP) {
         return;
     }
 
-    let nb = lbits(&mut n3, &mut n);
+    let nb=lbits(&mut n3,&mut n);
 
     let mut Q = ECP::new();
     Q.copy(QV);
@@ -273,28 +269,25 @@ pub fn another_pc(r: &mut [FP48], T: &[FP16], QV: &ECP) {
     let qx = FP::new_copy(&Q.getpx());
     let qy = FP::new_copy(&Q.getpy());
 
-    let mut j = 0;
-    for i in (1..nb - 1).rev() {
-        let mut lv = unpack(&T[j], &qx, &qy);
-        j += 1;
-        let bt = n3.bit(i) - n.bit(i);
-        if bt == 1 {
-            let lv2 = unpack(&T[j], &qx, &qy);
-            j += 1;
-            lv.smul(&lv2);
-        }
-        if bt == -1 {
-            let lv2 = unpack(&T[j], &qx, &qy);
-            j += 1;
-            lv.smul(&lv2);
-        }
+    let mut j=0;
+    for i in (1..nb-1).rev() {
+        let mut lv=unpack(&T[j],&qx,&qy); j+=1;
+	let bt=n3.bit(i)-n.bit(i);
+	if bt==1 {
+	    let lv2=unpack(&T[j],&qx,&qy); j+=1;
+	    lv.smul(&lv2);
+	}
+	if bt==-1 {
+	    let lv2=unpack(&T[j],&qx,&qy); j+=1;
+	    lv.smul(&lv2);
+	}
         r[i].ssmul(&lv);
     }
 }
 
 /* Accumulate another set of line functions for n-pairing */
 #[allow(non_snake_case)]
-pub fn another(r: &mut [FP48], P1: &ECP8, Q1: &ECP) {
+pub fn another(r:&mut [FP48],P1: &ECP8,Q1: &ECP) {
     let mut n = BIG::new();
     let mut n3 = BIG::new();
 
@@ -302,7 +295,7 @@ pub fn another(r: &mut [FP48], P1: &ECP8, Q1: &ECP) {
         return;
     }
 
-    // P is needed in affine form for line function, Q for (Qx,Qy) extraction
+// P is needed in affine form for line function, Q for (Qx,Qy) extraction
     let mut P = ECP8::new();
     P.copy(P1);
     P.affine();
@@ -319,18 +312,18 @@ pub fn another(r: &mut [FP48], P1: &ECP8, Q1: &ECP) {
     NP.copy(&P);
     NP.neg();
 
-    let nb = lbits(&mut n3, &mut n);
+    let nb=lbits(&mut n3,&mut n);
 
-    for i in (1..nb - 1).rev() {
-        let mut lv = linedbl(&mut A, &qx, &qy);
+    for i in (1..nb-1).rev() {
+        let mut lv=linedbl(&mut A,&qx,&qy);
 
-        let bt = n3.bit(i) - n.bit(i);
-        if bt == 1 {
-            let lv2 = lineadd(&mut A, &P, &qx, &qy);
+	let bt=n3.bit(i)-n.bit(i);
+        if bt==1 {
+            let lv2=lineadd(&mut A,&P,&qx,&qy);
             lv.smul(&lv2);
         }
-        if bt == -1 {
-            let lv2 = lineadd(&mut A, &NP, &qx, &qy);
+        if bt==-1 {
+            let lv2=lineadd(&mut A,&NP,&qx,&qy);
             lv.smul(&lv2);
         }
         r[i].ssmul(&lv);
@@ -365,7 +358,7 @@ pub fn ate(P1: &ECP8, Q1: &ECP) -> FP48 {
     NP.copy(&P);
     NP.neg();
 
-    let nb = lbits(&mut n3, &mut n);
+    let nb=lbits(&mut n3,&mut n);
 
     for i in (1..nb - 1).rev() {
         r.sqr();
@@ -396,10 +389,10 @@ pub fn ate2(P1: &ECP8, Q1: &ECP, R1: &ECP8, S1: &ECP) -> FP48 {
     let mut n3 = BIG::new();
 
     if Q1.is_infinity() {
-        return ate(R1, S1);
+        return ate(R1,S1);
     }
     if S1.is_infinity() {
-        return ate(P1, Q1);
+        return ate(P1,Q1);
     }
 
     let mut P = ECP8::new();
@@ -435,25 +428,25 @@ pub fn ate2(P1: &ECP8, Q1: &ECP, R1: &ECP8, S1: &ECP) -> FP48 {
     NR.copy(&R);
     NR.neg();
 
-    let nb = lbits(&mut n3, &mut n);
+     let nb=lbits(&mut n3,&mut n);
 
     for i in (1..nb - 1).rev() {
         r.sqr();
         let mut lv = linedbl(&mut A, &qx, &qy);
         let lv2 = linedbl(&mut B, &sx, &sy);
-        lv.smul(&lv2);
+	lv.smul(&lv2);
         r.ssmul(&lv);
         let bt = n3.bit(i) - n.bit(i);
         if bt == 1 {
             lv = lineadd(&mut A, &P, &qx, &qy);
             let lv2 = lineadd(&mut B, &R, &sx, &sy);
-            lv.smul(&lv2);
+	    lv.smul(&lv2);
             r.ssmul(&lv);
         }
         if bt == -1 {
             lv = lineadd(&mut A, &NP, &qx, &qy);
             let lv2 = lineadd(&mut B, &NR, &sx, &sy);
-            lv.smul(&lv2);
+	    lv.smul(&lv2);
             r.ssmul(&lv);
         }
     }
@@ -485,78 +478,75 @@ pub fn fexp(m: &FP48) -> FP48 {
 
     /* Hard part of final exp */
 
-    // See https://eprint.iacr.org/2020/875.pdf
-    let mut y1 = FP48::new_copy(&r);
-    y1.usqr();
-    y1.mul(&r); // y1=r^3
+// See https://eprint.iacr.org/2020/875.pdf
+        let mut y1 = FP48::new_copy(&r);
+        y1.usqr();
+        y1.mul(&r); // y1=r^3
 
-    let mut y0 = FP48::new_copy(&r.pow(&x));
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
-        y0.conj();
-    }
-    let mut t0 = FP48::new_copy(&r);
-    t0.conj();
-    r.copy(&y0);
-    r.mul(&t0);
+        let mut y0 = FP48::new_copy(&r.pow(&x));
+        if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+            y0.conj();
+        }
+        let mut t0 = FP48::new_copy(&r); t0.conj();
+        r.copy(&y0);
+        r.mul(&t0);
 
-    y0.copy(&r.pow(&x));
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
-        y0.conj();
-    }
-    t0.copy(&r);
-    t0.conj();
-    r.copy(&y0);
-    r.mul(&t0);
+        y0.copy(&r.pow(&x));
+        if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+            y0.conj();
+        }
+        t0.copy(&r); t0.conj();
+        r.copy(&y0);
+        r.mul(&t0);
 
-    // ^(x+p)
-    y0.copy(&r.pow(&x));
-    if ecp::SIGN_OF_X == ecp::NEGATIVEX {
-        y0.conj();
-    }
-    t0.copy(&r);
-    t0.frob(&f, 1);
-    r.copy(&y0);
-    r.mul(&t0);
+// ^(x+p)
+        y0.copy(&r.pow(&x));
+        if ecp::SIGN_OF_X == ecp::NEGATIVEX {
+            y0.conj();
+        }
+        t0.copy(&r);
+        t0.frob(&f,1);
+        r.copy(&y0);
+        r.mul(&t0);
 
-    // ^(x^2+p^2)
-    y0.copy(&r.pow(&x));
-    y0.copy(&y0.pow(&x));
-    t0.copy(&r);
-    t0.frob(&f, 2);
-    r.copy(&y0);
-    r.mul(&t0);
+// ^(x^2+p^2)
+        y0.copy(&r.pow(&x));
+        y0.copy(&y0.pow(&x));
+        t0.copy(&r);
+        t0.frob(&f,2); 
+        r.copy(&y0);
+        r.mul(&t0);
 
-    // ^(x^4+p^4)
-    y0.copy(&r.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    t0.copy(&r);
-    t0.frob(&f, 4);
-    r.copy(&y0);
-    r.mul(&t0);
+// ^(x^4+p^4)
+        y0.copy(&r.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        t0.copy(&r);
+        t0.frob(&f,4);
+        r.copy(&y0);
+        r.mul(&t0);
 
-    // ^(x^+p^8-1)
-    y0.copy(&r.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    y0.copy(&y0.pow(&x));
-    t0.copy(&r);
-    t0.frob(&f, 8);
-    y0.mul(&t0);
-    t0.copy(&r);
-    t0.conj();
-    r.copy(&y0);
-    r.mul(&t0);
+// ^(x^+p^8-1)
+        y0.copy(&r.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        y0.copy(&y0.pow(&x));
+        t0.copy(&r);
+        t0.frob(&f,8);
+        y0.mul(&t0);
+        t0.copy(&r); t0.conj();
+        r.copy(&y0);
+        r.mul(&t0);
 
-    r.mul(&y1);
-    r.reduce();
+        r.mul(&y1);
+        r.reduce();
 
-    /*
+/*
     // Ghamman & Fouotsa Method
 
     let mut t7 = FP48::new_copy(&r);
@@ -869,7 +859,7 @@ pub fn g2mul(P: &ECP8, e: &BIG) -> ECP8 {
             Q[i].copy(&T);
             Q[i].frob(&f, 1);
         }
-        //println!("");
+	//println!("");
         for i in 0..16 {
             let np = u[i].nbits();
             t.copy(&BIG::modneg(&mut u[i], &q));
@@ -879,8 +869,8 @@ pub fn g2mul(P: &ECP8, e: &BIG) -> ECP8 {
                 Q[i].neg();
             }
             u[i].norm();
-            //println!("Q= {}",Q[i].tostring());
-            //println!("u= {}",u[i].tostring());
+	    //println!("Q= {}",Q[i].tostring());
+	    //println!("u= {}",u[i].tostring());
         }
 
         R.copy(&ECP8::mul16(&mut Q, &u));
@@ -949,7 +939,7 @@ pub fn g1member(P: &ECP) -> bool {
     if P.is_infinity() {
         return false;
     }
-    let W = g1mul(&P, &q);
+    let W=g1mul(&P,&q);
     if !W.is_infinity() {
         return false;
     }
@@ -963,7 +953,7 @@ pub fn g2member(P: &ECP8) -> bool {
     if P.is_infinity() {
         return false;
     }
-    let W = g2mul(&P, &q);
+    let W=g2mul(&P,&q);
     if !W.is_infinity() {
         return false;
     }
@@ -983,19 +973,18 @@ pub fn gtmember(m: &FP48) -> bool {
         return false;
     }
     let f = FP2::new_bigs(&BIG::new_ints(&rom::FRA), &BIG::new_ints(&rom::FRB));
-    r.copy(&m);
-    r.frob(&f, 8);
-    let mut w = FP48::new_copy(&r);
-    w.frob(&f, 8);
+    r.copy(&m); r.frob(&f,8); 
+    let mut w = FP48::new_copy(&r); w.frob(&f,8); 
     w.mul(&m);
     if !w.equals(&r) {
         return false;
     }
     let q = BIG::new_ints(&rom::CURVE_ORDER);
     w.copy(&m);
-    r.copy(&gtpow(&w, &q));
+    r.copy(&gtpow(&w,&q));
     if !r.isunity() {
         return false;
     }
     true
 }
+
